@@ -5,7 +5,9 @@
 
 #include "detection/displayserver/displayserver.h"
 
-void ffdsConnectWayland(FFDisplayServerResult* result);
+bool ffdsMatchDrmConnector(const char* connName, FFstrbuf* edidName);
+
+const char* ffdsConnectWayland(FFDisplayServerResult* result);
 
 void ffdsConnectXcbRandr(FFDisplayServerResult* result);
 void ffdsConnectXcb(FFDisplayServerResult* result);
@@ -17,4 +19,6 @@ void ffdsConnectDrm(FFDisplayServerResult* result);
 
 void ffdsDetectWMDE(FFDisplayServerResult* result);
 
+FFDisplayType ffdsGetDisplayType(const char* drmConnectorName);
+
 #endif
