@@ -1,8 +1,5 @@
 #pragma once
 
-#ifndef FF_INCLUDED_detection_sound_sound
-#define FF_INCLUDED_detection_sound_sound
-
 #include "fastfetch.h"
 
 #define FF_SOUND_VOLUME_UNKNOWN 255
@@ -16,6 +13,4 @@ typedef struct FFSoundDevice
     bool active;
 } FFSoundDevice;
 
-const char* ffDetectSound(const FFinstance* instance, FFlist* devices /* List of FFSoundDevice */);
-
-#endif
+const char* ffDetectSound(FFlist* devices /* List of FFSoundDevice */);
